@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    Copyright 2010 Reto Zingg <g.d0b3rm4n@gmail.com>
+    Copyright 2010, 2011 Reto Zingg <g.d0b3rm4n@gmail.com>
 
  ***************************************************************************/
 
@@ -18,6 +18,7 @@
 #include "qmtrainer.h"
 #include "qmmultiplechoice.h"
 #include "qmflashcard.h"
+#include "lessonchoosewidget.h"
 
 #include <QComboBox>
 #include <QHBoxLayout>
@@ -26,6 +27,7 @@
 #include <QPushButton>
 #include <QTimer>
 #include <QCheckBox>
+#include <QList>
 #include <QDebug>
 
 TrainingSelectionView::TrainingSelectionView(QWidget* parent) : QWidget(parent)
@@ -40,7 +42,15 @@ TrainingSelectionView::TrainingSelectionView(QWidget* parent) : QWidget(parent)
     QHBoxLayout *hbox_bottom = new QHBoxLayout();
 
     m_ComboDictionary = new QComboBox();
-    m_ComboLesson = new QComboBox();
+
+    QPushButton *m_buttonLesson = new QPushButton();
+    m_buttonLesson->setText(tr("Choose Lessons"));
+
+    connect(m_buttonLesson,
+            SIGNAL(clicked()),
+            this,
+            SLOT(slotLessonDialog()));
+
     m_ComboQuestionLang = new QComboBox();
     m_ComboAnswerLang = new QComboBox();
     m_ComboTrainer = new QComboBox();
@@ -56,7 +66,7 @@ TrainingSelectionView::TrainingSelectionView(QWidget* parent) : QWidget(parent)
 
     QLabel *label_lesson = new QLabel(tr("Lesson:"));
     hbox_lession->addWidget(label_lesson);
-    hbox_lession->addWidget(m_ComboLesson);
+    hbox_lession->addWidget(m_buttonLesson);
 
     QLabel *label_question = new QLabel(tr("Question:"));
     hbox_question_lang->addWidget(label_question);
@@ -70,7 +80,6 @@ TrainingSelectionView::TrainingSelectionView(QWidget* parent) : QWidget(parent)
     hbox_trainer->addWidget(label_trainer);
     hbox_trainer->addWidget(m_ComboTrainer);
 
-    m_checkbox = new QCheckBox(tr("Portrait"), this);
     m_checkbox_random = new QCheckBox(tr("Random"), this);
 
     QPushButton *m_button = new QPushButton();
@@ -86,9 +95,13 @@ TrainingSelectionView::TrainingSelectionView(QWidget* parent) : QWidget(parent)
     vbox->addLayout(hbox_question_lang);
     vbox->addLayout(hbox_answer_lang);
     vbox->addLayout(hbox_trainer);
-    hbox_bottom->addWidget(m_checkbox);
+#ifdef Q_WS_MAEMO_5
+    m_checkbox_portrait = new QCheckBox(tr("Portrait"), this);
+    hbox_bottom->addWidget(m_checkbox_portrait);
+#endif
     hbox_bottom->addWidget(m_checkbox_random);
     hbox_bottom->addWidget(m_button);
+
     vbox->addLayout(hbox_bottom);
 
     setLayout(vbox);
@@ -101,6 +114,9 @@ TrainingSelectionView::TrainingSelectionView(QWidget* parent) : QWidget(parent)
             SIGNAL(activated(int)),
             SLOT(slotDictionarySelected(int)));
 
+    m_TrainingLessons = new QList<int>;
+    m_TrainingLessons->append(0);
+
     QTimer::singleShot(1000,this,SLOT(slotInitView()));
 }
 
@@ -142,7 +158,7 @@ void TrainingSelectionView::start()
         trainer->setRandomOnly(m_checkbox_random->isChecked());
         trainer->setQuestionLanguage(m_ComboQuestionLang->currentIndex());
         trainer->setAnswerLanguage(m_ComboAnswerLang->currentIndex());
-        trainer->setLession(m_ComboLesson->currentIndex());
+        trainer->setLesson(m_TrainingLessons);
         trainer->setQmVocDocument(settings->getQmVocDocument());
         trainer->setCurrentFileName(settings->getCurrentlyOpenedFile());
 
@@ -153,7 +169,7 @@ void TrainingSelectionView::start()
                     * it's not possible to have Portrait and Stackedwindows
                     * so we have either one
                     */
-        if(m_checkbox->isChecked() == true){
+        if(m_checkbox_portrait->isChecked() == true){
             trainer->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
         } else {
             trainer->setAttribute(Qt::WA_Maemo5StackedWindow, true);
@@ -174,18 +190,18 @@ void TrainingSelectionView::slotDictionaryChanged()
     QueryMeeSettings* settings = QueryMeeSettings::instance();
 
     m_ComboDictionary->clear();
-    m_ComboLesson->clear();
     m_ComboQuestionLang->clear();
     m_ComboAnswerLang->clear();
+    m_TrainingLessons->clear();
 
     m_ComboDictionary->addItems(settings->dictionaries());
-    m_ComboLesson->addItems(settings->lessons());
     m_ComboQuestionLang->addItems(settings->languages());
     m_ComboAnswerLang->addItems(settings->languages());
 
     m_ComboDictionary->setCurrentIndex(settings->openedDictionary());
     m_ComboQuestionLang->setCurrentIndex(0);
     m_ComboAnswerLang->setCurrentIndex(1);
+    m_TrainingLessons->append(0);
 
 #ifdef Q_WS_MAEMO_5
     this->parentWidget()->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
@@ -199,3 +215,18 @@ void TrainingSelectionView::slotDictionarySelected(int index)
         QueryMeeSettings::instance()->openDictionary(dictionaryName);
     }
 }
+
+void TrainingSelectionView::slotLessonDialog(){
+    QueryMeeSettings *settings = QueryMeeSettings::instance();
+    LessonChooseWidget *lessonDialog = new LessonChooseWidget(this, settings);
+    lessonDialog->setWindowFlags(lessonDialog->windowFlags() | Qt::Window);
+#ifdef Q_WS_MAEMO_5
+    lessonDialog->setAttribute(Qt::WA_Maemo5StackedWindow, true);
+#endif
+    lessonDialog->show();
+}
+
+void TrainingSelectionView::setTrainingsLessons(QList<int> *trainingLessons){
+    m_TrainingLessons->clear();
+    m_TrainingLessons = trainingLessons;
+}
